from flask import current_app
from flask_jwt_extended import get_jwt
import ory_kratos_client
from ory_kratos_client.api import identity_api

from .models import App, AppRole
from config import *
from helpers.access_control import user_has_access
from helpers.kratos_user import KratosUser

class AppsService:
    @staticmethod
    def get_all_apps():
        apps = App.query.all()
        return [app.to_dict() for app in apps]

    @staticmethod
    def get_accessible_apps():
        apps = App.query.all()

        kratos_admin_api_configuration = ory_kratos_client.Configuration(host=KRATOS_ADMIN_URL, discard_unknown_keys=True)
        with ory_kratos_client.ApiClient(kratos_admin_api_configuration) as kratos_admin_client:
            kratos_identity_api = identity_api.IdentityApi(kratos_admin_client)

            user_id = get_jwt()['user_id']
            current_app.logger.info(f"user_id: {user_id}")
            # Get the related user object
            current_app.logger.info(f"Info: Getting user from admin {user_id}")
            user = KratosUser(kratos_identity_api, user_id)
            if not user:
                current_app.logger.error(f"User not found in database: {user_id}")
                return []

            return [app.to_dict() for app in apps if user_has_access(user, app)]

    @staticmethod
    def get_app(slug):
        app = App.query.filter_by(slug=slug).first()
        return app.to_dict()

    @staticmethod
    def get_app_roles():
        app_roles = AppRole.query.all()
        return [{"user_id": app_role.user_id, "app_id": app_role.app_id, "role_id": app_role.role_id} for app_role in app_roles]
